@@ -2,16 +2,13 @@
 # Copyright (C) 2020 Arm Mbed. All rights reserved.
 # SPDX-License-Identifier: Apache-2.0
 #
-"""Command to generate the application CMake configuration script used by the build system."""
+"""Command to generate the application CMake configuration script used by the build/compile system."""
 import pathlib
 
 import click
 
 from mbed_tools.project import MbedProgram
-from mbed_tools.targets import get_target_by_name
-from mbed_tools.build._internal.cmake_file import generate_mbed_config_cmake_file
-from mbed_tools.build._internal.config.assemble_build_config import assemble_config
-from mbed_tools.build._internal.write_files import write_file
+from mbed_tools.build import generate_config
 
 
 @click.command(
@@ -32,7 +29,10 @@ from mbed_tools.build._internal.write_files import write_file
     default=".",
     help="Path to local Mbed program. By default is the current working directory.",
 )
-def configure(toolchain: str, mbed_target: str, program_path: str) -> None:
+@click.option(
+    "--mbed-os-path", type=click.Path(), default=None, help="Path to local Mbed OS directory.",
+)
+def configure(toolchain: str, mbed_target: str, program_path: str, mbed_os_path: str) -> None:
     """Exports a mbed_config.cmake file to a .mbedbuild directory in the program root.
 
     The parameters set in the CMake file will be dependent on the combination of
@@ -46,12 +46,12 @@ def configure(toolchain: str, mbed_target: str, program_path: str) -> None:
         toolchain: the toolchain you are using (eg. GCC_ARM, ARM)
         mbed_target: the target you are building for (eg. K64F)
         program_path: the path to the local Mbed program
+        mbed_os_path: the path to the local Mbed OS directory
     """
-    program = MbedProgram.from_existing(pathlib.Path(program_path))
+    if mbed_os_path is None:
+        program = MbedProgram.from_existing(pathlib.Path(program_path))
+    else:
+        program = MbedProgram.from_existing(pathlib.Path(program_path), pathlib.Path(mbed_os_path))
     mbed_target = mbed_target.upper()
-    target_build_attributes = get_target_by_name(mbed_target, program.mbed_os.targets_json_file)
-    config = assemble_config(target_build_attributes, program.root, program.files.app_config_file)
-    cmake_file_contents = generate_mbed_config_cmake_file(mbed_target, target_build_attributes, config, toolchain)
-    output_directory = program.root / ".mbedbuild"
-    write_file(output_directory, "mbed_config.cmake", cmake_file_contents)
-    click.echo(f"mbed_config.cmake has been generated and written to '{str(output_directory.resolve())}'")
+    output_path = generate_config(mbed_target, toolchain, program)
+    click.echo(f"mbed_config.cmake has been generated and written to '{str(output_path.resolve())}'")
