@@ -14,10 +14,10 @@ import click
 from mbed_tools.lib.logging import set_log_level, MbedToolsHandler
 
 from mbed_tools.cli.configure import configure
-from mbed_tools.cli.env_cli import cli as env_cli
 from mbed_tools.cli.list_connected_devices import list_connected_devices
-from mbed_tools.cli.project_management import init, clone, checkout, libs
-
+from mbed_tools.cli.project_management import new, import_, deploy
+from mbed_tools.cli.build import build
+from mbed_tools.cli.sterm import sterm
 
 CONTEXT_SETTINGS = dict(help_option_names=["-h", "--help"])
 LOGGER = logging.getLogger(__name__)
@@ -73,9 +73,9 @@ def cli(verbose: int, traceback: bool) -> None:
 
 
 cli.add_command(configure, "configure")
-cli.add_command(list_connected_devices, "devices")
-cli.add_command(env_cli, "env")
-cli.add_command(init, "init")
-cli.add_command(checkout, "checkout")
-cli.add_command(clone, "clone")
-cli.add_command(libs, "libs")
+cli.add_command(list_connected_devices, "detect")
+cli.add_command(new, "new")
+cli.add_command(deploy, "deploy")
+cli.add_command(import_, "import")
+cli.add_command(build, "compile")
+cli.add_command(sterm, "sterm")
