@@ -42,6 +42,10 @@ class MbedLibReference:
         """
         raw_ref = self.reference_file.read_text().strip()
         url, sep, ref = raw_ref.partition("#")
+
+        if url.endswith("/"):
+            url = url[:-1]
+
         return git_utils.GitReference(repo_url=url, ref=ref)
 
 
@@ -50,9 +54,9 @@ class LibraryReferences:
     """Manages library references in an MbedProgram."""
 
     root: Path
-    ignore_paths: List[Path]
+    ignore_paths: List[str]
 
-    def resolve(self) -> None:
+    def fetch(self) -> None:
         """Recursively clone all dependencies defined in .lib files."""
         for lib in self.iter_unresolved():
             git_ref = lib.get_git_reference()
@@ -64,15 +68,22 @@ class LibraryReferences:
 
         # Check if we find any new references after cloning dependencies.
         if list(self.iter_unresolved()):
-            self.resolve()
+            self.fetch()
 
     def checkout(self, force: bool) -> None:
         """Check out all resolved libs to revision specified in .lib files."""
         for lib in self.iter_resolved():
-            repo = git_utils.init(lib.source_code_path)
+            repo = git_utils.get_repo(lib.source_code_path)
             git_ref = lib.get_git_reference()
-            if git_ref.ref:
-                git_utils.checkout(repo, git_ref.ref, force=force)
+
+            if not git_ref.ref:
+                repo.git.fetch()
+                git_ref.ref = git_utils.get_default_branch(repo)
+            else:
+                # Fetch only the requested ref
+                repo.git.fetch("origin", git_ref.ref)
+
+            git_utils.checkout(repo, git_ref.ref, force=force)
 
     def iter_all(self) -> Generator[MbedLibReference, None, None]:
         """Iterate all library references in the tree.
@@ -106,4 +117,4 @@ class LibraryReferences:
 
     def _in_ignore_path(self, lib_reference_path: Path) -> bool:
         """Check if a library reference is in a path we want to ignore."""
-        return any(p in lib_reference_path.parents for p in self.ignore_paths)
+        return any(p in lib_reference_path.parts for p in self.ignore_paths)
