@@ -20,6 +20,8 @@ logger = logging.getLogger(__name__)
 
 # Mbed program file names and constants.
 APP_CONFIG_FILE_NAME = "mbed_app.json"
+CMAKE_CONFIG_FILE_PATH = Path(".mbedbuild", "mbed_config.cmake")
+CMAKE_BUILD_DIR = "cmake_build"
 CMAKELISTS_FILE_NAME = "CMakeLists.txt"
 MAIN_CPP_FILE_NAME = "main.cpp"
 MBED_OS_REFERENCE_FILE_NAME = "mbed-os.lib"
@@ -28,7 +30,7 @@ TARGETS_JSON_FILE_PATH = Path("targets", "targets.json")
 
 # Information written to mbed-os.lib
 MBED_OS_REFERENCE_URL = "https://github.com/ARMmbed/mbed-os"
-MBED_OS_REFERENCE_ID = "feature-cmake"
+MBED_OS_REFERENCE_ID = "master"
 
 # For some reason Mbed OS expects the default mbed_app.json to contain some target_overrides
 # for the K64F target. TODO: Find out why this wouldn't be defined in targets.json.
@@ -48,11 +50,15 @@ class MbedProgramFiles:
         app_config_file: Path to mbed_app.json file. This can be `None` if the program doesn't set any custom config.
         mbed_os_ref: Library reference file for MbedOS. All programs require this file.
         cmakelists_file: A top-level CMakeLists.txt containing build definitions for the application.
+        cmake_config_file: Path to the CMake configuration script.
+        cmake_build_dir: The CMake build tree.
     """
 
     app_config_file: Optional[Path]
     mbed_os_ref: Path
     cmakelists_file: Path
+    cmake_config_file: Path
+    cmake_build_dir: Path
 
     @classmethod
     def from_new(cls, root_path: Path) -> "MbedProgramFiles":
@@ -71,6 +77,8 @@ class MbedProgramFiles:
         cmakelists_file = root_path / CMAKELISTS_FILE_NAME
         main_cpp = root_path / MAIN_CPP_FILE_NAME
         gitignore = root_path / ".gitignore"
+        cmake_config = root_path / CMAKE_CONFIG_FILE_PATH
+        cmake_build_dir = root_path / CMAKE_BUILD_DIR
 
         if mbed_os_ref.exists():
             raise ValueError(f"Program already exists at path {root_path}.")
@@ -80,7 +88,13 @@ class MbedProgramFiles:
         render_cmakelists_template(cmakelists_file, root_path.stem)
         render_main_cpp_template(main_cpp)
         render_gitignore_template(gitignore)
-        return cls(app_config_file=app_config, mbed_os_ref=mbed_os_ref, cmakelists_file=cmakelists_file)
+        return cls(
+            app_config_file=app_config,
+            mbed_os_ref=mbed_os_ref,
+            cmakelists_file=cmakelists_file,
+            cmake_config_file=cmake_config,
+            cmake_build_dir=cmake_build_dir,
+        )
 
     @classmethod
     def from_existing(cls, root_path: Path) -> "MbedProgramFiles":
@@ -99,10 +113,15 @@ class MbedProgramFiles:
 
         cmakelists_file = root_path / CMAKELISTS_FILE_NAME
         if not cmakelists_file.exists():
-            logger.warning("No CMakeLists.txt found in the program root. Creating it...")
-            render_cmakelists_template(cmakelists_file, root_path.stem)
+            logger.warning("No CMakeLists.txt found in the program root.")
 
-        return cls(app_config_file=app_config, mbed_os_ref=mbed_os_file, cmakelists_file=cmakelists_file)
+        return cls(
+            app_config_file=app_config,
+            mbed_os_ref=mbed_os_file,
+            cmakelists_file=cmakelists_file,
+            cmake_config_file=root_path / CMAKE_CONFIG_FILE_PATH,
+            cmake_build_dir=root_path / CMAKE_BUILD_DIR,
+        )
 
 
 @dataclass
