@@ -6,18 +6,16 @@
 import logging
 
 from pathlib import Path
-from typing import List, Dict
+from typing import Dict
 from urllib.parse import urlparse
 
 from mbed_tools.project.exceptions import ProgramNotFound, ExistingProgram, MbedOSNotFound
-from mbed_tools.project._internal import git_utils
 from mbed_tools.project._internal.project_data import (
     MbedProgramFiles,
     MbedOS,
     MBED_OS_REFERENCE_FILE_NAME,
     MBED_OS_DIR_NAME,
 )
-from mbed_tools.project._internal.libraries import LibraryReferences, MbedLibReference
 
 logger = logging.getLogger(__name__)
 
@@ -26,7 +24,6 @@ class MbedProgram:
     """Represents an Mbed program.
 
     An `MbedProgram` consists of:
-        * A git repository
         * A copy of, or reference to, `MbedOS`
         * A set of `MbedProgramFiles`
         * A collection of references to external libraries, defined in .lib files located in the program source tree
@@ -42,42 +39,6 @@ class MbedProgram:
         self.files = program_files
         self.root = self.files.mbed_os_ref.parent
         self.mbed_os = mbed_os
-        self.lib_references = LibraryReferences(root=self.root, ignore_paths=[self.mbed_os.root])
-
-    @classmethod
-    def from_url(cls, url: str, dst_path: Path, check_mbed_os: bool = True) -> "MbedProgram":
-        """Fetch an Mbed program from a remote URL.
-
-        Args:
-            url: URL of the remote program repository.
-            dst_path: Destination path for the cloned program.
-
-        Raises:
-            ExistingProgram: `dst_path` already contains an Mbed program.
-        """
-        if _tree_contains_program(dst_path):
-            raise ExistingProgram(
-                f"The destination path '{dst_path}' already contains an Mbed program. Please set the destination path "
-                "to an empty directory."
-            )
-        logger.info(f"Cloning Mbed program from URL '{url}'.")
-        git_utils.clone(url, dst_path)
-
-        program_files = MbedProgramFiles.from_existing(dst_path)
-        if not program_files.mbed_os_ref.exists():
-            raise ProgramNotFound(
-                "This repository does not contain a valid Mbed program at the top level. "
-                "Cloned programs must contain an mbed-os.lib file containing the URL to the Mbed OS repository. It is "
-                "possible you have cloned a repository containing multiple mbed-programs. If this is the case, you "
-                "should cd to a directory containing a program before performing any other operations."
-            )
-
-        try:
-            mbed_os = MbedOS.from_existing(dst_path / MBED_OS_DIR_NAME, check_mbed_os)
-        except ValueError as mbed_err:
-            raise MbedOSNotFound(f"{mbed_err}")
-
-        return cls(program_files, mbed_os)
 
     @classmethod
     def from_new(cls, dir_path: Path) -> "MbedProgram":
@@ -105,47 +66,37 @@ class MbedProgram:
         return cls(program_files, mbed_os)
 
     @classmethod
-    def from_existing(cls, dir_path: Path, check_mbed_os: bool = True) -> "MbedProgram":
+    def from_existing(cls, dir_path: Path, mbed_os_path: Path = None, check_mbed_os: bool = True) -> "MbedProgram":
         """Create an MbedProgram from an existing program directory.
 
         Args:
             dir_path: Directory containing an Mbed program.
+            mbed_os_path: Directory containing Mbed OS
             check_mbed_os: If True causes an exception to be raised if the Mbed OS source directory does not
                            exist.
 
         Raises:
             ProgramNotFound: An existing program was not found in the path.
         """
-        program_root = _find_program_root(dir_path)
+        if mbed_os_path is None:
+            program_root = _find_program_root(dir_path)
+            mbed_os_path = program_root / MBED_OS_DIR_NAME
+        else:
+            program_root = dir_path
+
         logger.info(f"Found existing Mbed program at path '{program_root}'")
         program = MbedProgramFiles.from_existing(program_root)
 
         try:
-            mbed_os = MbedOS.from_existing(program_root / MBED_OS_DIR_NAME, check_mbed_os)
+            mbed_os = MbedOS.from_existing(mbed_os_path, check_mbed_os)
         except ValueError as mbed_os_err:
             raise MbedOSNotFound(
                 f"Mbed OS was not found due to the following error: {mbed_os_err}"
-                "\nYou may need to resolve the mbed-os.lib reference. You can do this by performing a `checkout`."
+                "\nYou may need to resolve the mbed-os.lib reference. You can do this by performing a `deploy`."
             )
 
         return cls(program, mbed_os)
 
-    def resolve_libraries(self) -> None:
-        """Resolve all external dependencies defined in .lib files."""
-        self.lib_references.resolve()
-
-    def checkout_libraries(self, force: bool = False) -> None:
-        """Check out all resolved libraries to revisions specified in .lib files."""
-        self.lib_references.checkout(force)
-
-    def list_known_library_dependencies(self) -> List[MbedLibReference]:
-        """Returns a list of all known library dependencies."""
-        return sorted([lib for lib in self.lib_references.iter_all()])
-
-    def has_unresolved_libraries(self) -> bool:
-        """Checks if any unresolved library dependencies exist in the program tree."""
-        return bool(list(self.lib_references.iter_unresolved()))
-
 
 def parse_url(name_or_url: str) -> Dict[str, str]:
     """Create a valid github/armmbed url from a program name.
