@@ -6,29 +6,37 @@
 import pathlib
 import logging
 
-from typing import Dict, Any
+from typing import List, Any
 
 from mbed_tools.project.mbed_program import MbedProgram, parse_url
+from mbed_tools.project._internal.libraries import LibraryReferences
+from mbed_tools.project._internal import git_utils
 
 logger = logging.getLogger(__name__)
 
 
-def clone_project(url: str, dst_path: Any = None, recursive: bool = False) -> None:
+def import_project(url: str, dst_path: Any = None, recursive: bool = False) -> pathlib.Path:
     """Clones an Mbed project from a remote repository.
 
     Args:
         url: URL of the repository to clone.
         dst_path: Destination path for the repository.
         recursive: Recursively clone all project dependencies.
+
+    Returns:
+        The path the project was cloned to.
     """
     git_data = parse_url(url)
     url = git_data["url"]
     if not dst_path:
         dst_path = pathlib.Path(git_data["dst_path"])
 
-    program = MbedProgram.from_url(url, dst_path, check_mbed_os=False)
+    git_utils.clone(url, dst_path)
     if recursive:
-        program.resolve_libraries()
+        libs = LibraryReferences(root=dst_path, ignore_paths=["mbed-os"])
+        libs.fetch()
+
+    return dst_path
 
 
 def initialise_project(path: pathlib.Path, create_only: bool) -> None:
@@ -40,29 +48,29 @@ def initialise_project(path: pathlib.Path, create_only: bool) -> None:
     """
     program = MbedProgram.from_new(path)
     if not create_only:
-        program.resolve_libraries()
+        libs = LibraryReferences(root=program.root, ignore_paths=["mbed-os"])
+        libs.fetch()
 
 
-def checkout_project_revision(path: pathlib.Path, force: bool = False) -> None:
-    """Checkout a specific revision of the current Mbed project.
+def deploy_project(path: pathlib.Path, force: bool = False) -> None:
+    """Deploy a specific revision of the current Mbed project.
 
     This function also resolves and syncs all library dependencies to the revision specified in the library reference
     files.
 
     Args:
         path: Path to the Mbed project.
-        project_revision: Revision of the Mbed project to check out.
-        force: Force overwrite uncommitted changes. If False, the checkout will fail if there are uncommitted local
+        force: Force overwrite uncommitted changes. If False, the deploy will fail if there are uncommitted local
                changes.
     """
-    program = MbedProgram.from_existing(path, check_mbed_os=False)
-    program.checkout_libraries(force=force)
-    if program.has_unresolved_libraries():
+    libs = LibraryReferences(path, ignore_paths=["mbed-os"])
+    libs.checkout(force=force)
+    if list(libs.iter_unresolved()):
         logger.info("Unresolved libraries detected, downloading library source code.")
-        program.resolve_libraries()
+        libs.fetch()
 
 
-def get_known_libs(path: pathlib.Path) -> Dict[str, Any]:
+def get_known_libs(path: pathlib.Path) -> List:
     """List all resolved library dependencies.
 
     This function will not resolve dependencies. This will only generate a list of resolved dependencies.
@@ -71,9 +79,7 @@ def get_known_libs(path: pathlib.Path) -> Dict[str, Any]:
         path: Path to the Mbed project.
 
     Returns:
-        dictionary containing a list of known dependencies and a boolean stating whether unresolved dependencies were
-        detected.
+        A list of known dependencies.
     """
-    program = MbedProgram.from_existing(path, check_mbed_os=False)
-
-    return {"known_libs": program.list_known_library_dependencies(), "unresolved": program.has_unresolved_libraries()}
+    libs = LibraryReferences(path, ignore_paths=["mbed-os"])
+    return list(sorted(libs.iter_resolved()))
